"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAsync = exports.UseAsyncState = void 0;
const react_1 = require("react");
var UseAsyncState;
(function (UseAsyncState) {
    UseAsyncState["unknown"] = "unknown";
    UseAsyncState["error"] = "error";
    UseAsyncState["done"] = "done";
})(UseAsyncState || (exports.UseAsyncState = UseAsyncState = {}));
const useAsync = (callback, deps) => {
    const [result, setResult] = (0, react_1.useState)({
        state: UseAsyncState.unknown,
    });
    (0, react_1.useEffect)(() => {
        setResult({
            state: UseAsyncState.unknown,
        });
        const controller = new AbortController();
        const { signal } = controller;
        callback(signal).then(value => {
            if (!signal.aborted) {
                setResult({
                    state: UseAsyncState.done,
                    value,
                });
            }
        }, error => {
            if (!signal.aborted) {
                setResult({
                    state: UseAsyncState.error,
                    error,
                });
            }
        });
        return () => {
            controller.abort();
        };
    }, [...deps, setResult]);
    return result;
};
exports.useAsync = useAsync;
