import { useEffect, useState } from 'react';
export var UseAsyncState;
(function (UseAsyncState) {
    UseAsyncState["unknown"] = "unknown";
    UseAsyncState["error"] = "error";
    UseAsyncState["done"] = "done";
})(UseAsyncState || (UseAsyncState = {}));
export const useAsync = (callback, deps) => {
    const [result, setResult] = useState({
        state: UseAsyncState.unknown,
    });
    useEffect(() => {
        setResult({
            state: UseAsyncState.unknown,
        });
        const controller = new AbortController();
        const { signal } = controller;
        callback(signal).then(value => {
            if (!signal.aborted) {
                setResult({
                    state: UseAsyncState.done,
                    value,
                });
            }
        }, error => {
            if (!signal.aborted) {
                setResult({
                    state: UseAsyncState.error,
                    error,
                });
            }
        });
        return () => {
            controller.abort();
        };
    }, [...deps, setResult]);
    return result;
};
